[Libreoffice-commits] core.git: javaunohelper/com jurt/com l10ntools/source sw/source

Andrea Gelmini andrea.gelmini at gelma.net
Fri Jun 23 09:52:45 UTC 2017


 javaunohelper/com/sun/star/comp/helper/ComponentContext.java |    2 +-
 jurt/com/sun/star/comp/loader/JavaLoader.java                |    2 +-
 jurt/com/sun/star/comp/servicemanager/ServiceManager.java    |   10 +++++-----
 l10ntools/source/gL10nMem.cxx                                |    2 +-
 sw/source/core/layout/tabfrm.cxx                             |    2 +-
 sw/source/filter/ww8/ww8par3.cxx                             |    2 +-
 6 files changed, 10 insertions(+), 10 deletions(-)

New commits:
commit a3a40ba2a6d7c8b32234b223831a0269b06a240c
Author: Andrea Gelmini <andrea.gelmini at gelma.net>
Date:   Fri Jun 23 11:03:20 2017 +0200

    Fix typos: uniform registered
    
    We have in the same files "registered" and "registred".
    
    Change-Id: I604a8fdb7d5c40fe208fc11e9120333b3eaef3da
    Reviewed-on: https://gerrit.libreoffice.org/39097
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>
    Tested-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/javaunohelper/com/sun/star/comp/helper/ComponentContext.java b/javaunohelper/com/sun/star/comp/helper/ComponentContext.java
index b280f80cbeaf..34649d563395 100644
--- a/javaunohelper/com/sun/star/comp/helper/ComponentContext.java
+++ b/javaunohelper/com/sun/star/comp/helper/ComponentContext.java
@@ -291,7 +291,7 @@ public class ComponentContext implements XComponentContext, XComponent
         if (xListener == null)
             throw new com.sun.star.uno.RuntimeException( "Listener must not be null" );
           if (m_eventListener.contains( xListener ))
-              throw new com.sun.star.uno.RuntimeException( "Listener already registred." );
+              throw new com.sun.star.uno.RuntimeException( "Listener already registered." );
 
            m_eventListener.add( xListener );
     }
diff --git a/jurt/com/sun/star/comp/loader/JavaLoader.java b/jurt/com/sun/star/comp/loader/JavaLoader.java
index 6c5b4cc97023..8bc0ae228593 100644
--- a/jurt/com/sun/star/comp/loader/JavaLoader.java
+++ b/jurt/com/sun/star/comp/loader/JavaLoader.java
@@ -356,7 +356,7 @@ public class JavaLoader implements XImplementationLoader,
      * the call is delegated to that method. Otherwise a default registration
      * will be accomplished.</p>
      *
-     * @param       regKey                  the root key under that the component should be registred.
+     * @param       regKey                  the root key under that the component should be registered.
      * @param       implementationLoaderUrl specifies the loader, the component is loaded by.
      * @param       locationUrl             points to an archive (JAR file) which contains a component.
      * @return      true if registration is successfully - otherwise false.
diff --git a/l10ntools/source/gL10nMem.cxx b/l10ntools/source/gL10nMem.cxx
index 0e71fcedd4bb..1a12b1d884c3 100644
--- a/l10ntools/source/gL10nMem.cxx
+++ b/l10ntools/source/gL10nMem.cxx
@@ -922,7 +922,7 @@ void l10nMem::addKey(int             iLineNo,
         l10nMem_file_entry& curF = mcFileList[miCurFileInx];
         vector<l10nMem_enus_entry>::iterator it = mcENUSlist.begin();
 
-        // file is registred, so we need to add the entry at the end of the file range
+        // file is registered, so we need to add the entry at the end of the file range
         curF.miEnd++;
         miCurENUSinx = curF.miEnd;
         mcENUSlist.insert(it + curF.miEnd,
diff --git a/sw/source/core/layout/tabfrm.cxx b/sw/source/core/layout/tabfrm.cxx
index 680f228899d8..ad5364568728 100644
--- a/sw/source/core/layout/tabfrm.cxx
+++ b/sw/source/core/layout/tabfrm.cxx
@@ -3509,7 +3509,7 @@ void SwTabFrame::Paste( SwFrame* pParent, SwFrame* pSibling )
     OSL_ENSURE( pParent != this, "I'm the parent myself." );
     OSL_ENSURE( pSibling != this, "I'm my own neighbour." );
     OSL_ENSURE( !GetPrev() && !GetNext() && !GetUpper(),
-            "I'm still registred somewhere." );
+            "I'm still registered somewhere." );
 
     //Insert in the tree.
     InsertBefore( static_cast<SwLayoutFrame*>(pParent), pSibling );
diff --git a/sw/source/filter/ww8/ww8par3.cxx b/sw/source/filter/ww8/ww8par3.cxx
index 4e71a6daff6b..19ca8dee7437 100644
--- a/sw/source/filter/ww8/ww8par3.cxx
+++ b/sw/source/filter/ww8/ww8par3.cxx
@@ -2030,7 +2030,7 @@ void SwWW8ImplReader::Read_LFOPosition(sal_uInt16, const sal_uInt8* pData,
             if (m_pAktColl && (m_nLFOPosition == 2047-1) && m_nAktColl < m_vColl.size())
                 m_vColl[m_nAktColl].m_bHasBrokenWW6List = true;
 
-            // here the stream data is 1-based, we substact ONE
+            // here the stream data is 1-based, we subtract ONE
             if (USHRT_MAX > m_nLFOPosition)
             {
                 if (m_nLFOPosition != 2047-1) //Normal ww8+ list behaviour


More information about the Libreoffice-commits mailing list
diff --git a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
index 3d06da79b62b..a8b6ab31b64a 100644
--- a/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
+++ b/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
@@ -309,7 +309,7 @@ public class ServiceManager implements XMultiServiceFactory,
      * <p>The listener is notified when a service is added (removed) to (from)
      * the <code>ServiceManager</code>.</p>
      *
      * <p>If the listener is already registred a
      * <code>com.sun.star.uno.RuntimeException</code> will be thrown.</p>
      *
      * @param   xListener   the new listener which should been added.
@@ -322,7 +322,7 @@ public class ServiceManager implements XMultiServiceFactory,
             throw new com.sun.star.uno.RuntimeException("Listener must not be null");
 
           if ( eventListener.contains(xListener) )
-              throw new com.sun.star.uno.RuntimeException("Listener already registred.");
+              throw new com.sun.star.uno.RuntimeException("Listener already registered.");
 
            eventListener.add(xListener);
     }
@@ -355,7 +355,7 @@ public class ServiceManager implements XMultiServiceFactory,
      * interface.</p>
      *
      * @param   object object which provides a <code>XServiceInfo</code> interface.
      * @return  true if the component is registred otherwise false.
      *
      * @see     com.sun.star.container.XSet
      * @see     com.sun.star.lang.XServiceInfo
@@ -395,7 +395,7 @@ public class ServiceManager implements XMultiServiceFactory,
 
         if ( factoriesByImplNames.containsKey( xServiceInfo.getImplementationName() ) ) {
             throw new com.sun.star.container.ElementExistException(
-                xServiceInfo.getImplementationName() + " already registred"
+                xServiceInfo.getImplementationName() + " already registered"
             );
         }
 
@@ -508,7 +508,7 @@ public class ServiceManager implements XMultiServiceFactory,
     /**
      * Checks if the any components are registered.
      *
      * @return  true - if the list of the registred components is not empty - otherwise false.
      * @see     com.sun.star.container.XElementAccess
      */
     public boolean hasElements() {
@@ -309,7 +309,7 @@ public class ServiceManager implements XMultiServiceFactory,
      * the <code>ServiceManager</code>.</p>
      *
-     * <p>If the listener is already registred a
+     * <p>If the listener is already registered a
      * <code>com.sun.star.uno.RuntimeException</code> will be thrown.</p>
      *
@@ -355,7 +355,7 @@ public class ServiceManager implements XMultiServiceFactory,
      *
      * @param   object object which provides a <code>XServiceInfo</code> interface.
-     * @return  true if the component is registred otherwise false.
+     * @return  true if the component is registered otherwise false.
      *
      * @see     com.sun.star.container.XSet
@@ -508,7 +508,7 @@ public class ServiceManager implements XMultiServiceFactory,
      * Checks if the any components are registered.
      *
-     * @return  true - if the list of the registred components is not empty - otherwise false.
+     * @return  true - if the list of the registered components is not empty - otherwise false.
      * @see     com.sun.star.container.XElementAccess
      */